@@ -1,6 +1,6 @@
 # This file is part of nvitop, the interactive NVIDIA-GPU process viewer.
 #
-# Copyright 2021-2024 Xuehai Pan. All Rights Reserved.
+# Copyright 2021-2025 Xuehai Pan. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,18 @@ import sys
 
 from nvitop import api
 from nvitop.api import *  # noqa: F403
-from nvitop.api import collector, device, host, libcuda, libcudart, libnvml, process, utils
+from nvitop.api import (
+    caching,
+    collector,
+    device,
+    host,
+    libcuda,
+    libcudart,
+    libnvml,
+    process,
+    termcolor,
+    utils,
+)
 from nvitop.select import select_devices
 from nvitop.version import __version__
 
@@ -28,7 +39,18 @@ from nvitop.version import __version__
 __all__ = [*api.__all__, 'select_devices']
 
 # Add submodules to the top-level namespace
-for submodule in (collector, device, host, libcuda, libcudart, libnvml, process, utils):
+for submodule in (
+    caching,
+    collector,
+    device,
+    host,
+    libcuda,
+    libcudart,
+    libnvml,
+    process,
+    termcolor,
+    utils,
+):
     sys.modules[f'{__name__}.{submodule.__name__.rpartition(".")[-1]}'] = submodule
 
 # Remove the nvitop.select module from sys.modules
