@@ -277,7 +277,7 @@ class CUDAError(Exception):
         return CUDAError, (self.value,)  # pylint: disable=no-member
 
 
-def cudaExceptionClass(cudaErrorCode: int) -> type[CUDAError]:
+def cudaExceptionClass(cudaErrorCode: int, /) -> type[CUDAError]:
     """Map value to a proper subclass of :class:`CUDAError`.
 
     Raises:
@@ -348,7 +348,7 @@ _extract_cuda_errors_as_classes()
 del _extract_cuda_errors_as_classes
 
 
-def _cudaCheckReturn(ret: _Any) -> _Any:
+def _cudaCheckReturn(ret: _Any, /) -> _Any:
     if ret != CUDA_SUCCESS:
         raise CUDAError(ret)
     return ret
@@ -522,7 +522,7 @@ def cuDriverGetVersion() -> str:
     """
     fn = __cudaGetFunctionPointer('cuDriverGetVersion')
 
-    driver_version = _ctypes.c_int()
+    driver_version = _ctypes.c_int(0)
     ret = fn(_ctypes.byref(driver_version))
     _cudaCheckReturn(ret)
     major = driver_version.value // 1000
@@ -733,7 +733,7 @@ def cuDeviceTotalMem(device: _c_CUdevice_t) -> int:
     """
     fn = __cudaGetFunctionPointer('cuDeviceTotalMem')
 
-    bytes = _ctypes.c_size_t()  # pylint: disable=redefined-builtin
+    bytes = _ctypes.c_size_t(0)  # pylint: disable=redefined-builtin
     ret = fn(_ctypes.byref(bytes), device)
     _cudaCheckReturn(ret)
     return bytes.value
