@@ -49,7 +49,7 @@ if TYPE_CHECKING:
     from nvitop.api.device import Device
 
 
-__all__ = ['HostProcess', 'GpuProcess', 'command_join']
+__all__ = ['GpuProcess', 'HostProcess', 'command_join']
 
 
 if host.POSIX:
@@ -95,8 +95,7 @@ def command_join(cmdline: list[str]) -> str:
     """Return a shell-escaped string from command line arguments."""
     if len(cmdline) == 1 and not (
         # May be modified by `setproctitle`
-        os.path.isfile(cmdline[0])
-        and os.path.isabs(cmdline[0])
+        os.path.isfile(cmdline[0]) and os.path.isabs(cmdline[0])
     ):
         return cmdline[0]
     return ' '.join(map(add_quotes, cmdline))
@@ -115,9 +114,9 @@ def auto_garbage_clean(
     raises an exception when falls.
     """
 
-    def wrapper(func: Callable[..., Any]) -> Callable[..., Any]:
+    def wrapper(func: Callable[..., Any], /) -> Callable[..., Any]:
         @functools.wraps(func)
-        def wrapped(self: GpuProcess, *args: Any, **kwargs: Any) -> Any:
+        def wrapped(self: GpuProcess, /, *args: Any, **kwargs: Any) -> Any:
             try:
                 return func(self, *args, **kwargs)
             except host.PsutilError as ex:
@@ -238,7 +237,7 @@ class HostProcess(host.Process, ABC):
 
     def __repr__(self) -> str:
         """Return a string representation of the process."""
-        return super().__repr__().replace(self.__class__.__module__ + '.', '', 1)
+        return super().__repr__().replace(f'{self.__class__.__module__}.', '', 1)
 
     def __reduce__(self) -> tuple[type[HostProcess], tuple[int]]:
         """Return state information for pickling."""
